@@ -20,7 +20,7 @@ class Model(object):
         self._attrs = dict((snake_to_camel(key), value) for (key, value) in kwargs.items())
 
     def __dir__(self):
-        attrs = set(self.__dict__.keys() + [camel_to_snake(key) for key in self._attrs.keys()])
+        attrs = set(list(self.__dict__.keys()) + [camel_to_snake(key) for key in self._attrs.keys()])
         if self._obj is not None:
             attrs.update(camel_to_snake(t.tag) for t in self._obj.iterchildren())
         return [attr for attr in attrs if not attr.startswith('_')]
@@ -64,7 +64,8 @@ class Model(object):
         lxml.etree.dump(self._obj, *args, **kwargs)
 
     def __repr__(self):
-        return "<%s.%s: %s>" % (type(self).__module__, type(self).__name__, self)
+        args = ', '.join('%s=%r' % (attr, getattr(self, attr)) for attr in dir(self))
+        return "<%s.%s(%s)>" % (type(self).__module__, type(self).__name__, args)
 
     def __str__(self):
         return str(lxml.etree.tostring(self._obj)) if self._obj is not None else 'Empty model'
@@ -112,6 +113,10 @@ class Name(Model):
         Last name
     """
 
+    def __eq__(self, other):
+        attributes = ['initials', 'first_name', 'prefix', 'last_name']
+        return all(getattr(self, attr, None) == getattr(other, attr, None) for attr in attributes)
+
     def __str__(self):
         if getattr(self, "prefix", None):
             return "%s %s %s" % (self.first_name, self.prefix, self.last_name)
@@ -251,7 +256,10 @@ class Address(Model):
     state (optional)
     country (required)
     """
-    pass
+
+    def __eq__(self, other):
+        attributes = ['street', 'number', 'suffix', 'zipcode', 'city', 'state', 'country']
+        return all(getattr(self, attr, None) == getattr(other, attr, None) for attr in attributes)
 
 
 class Phone(Model):
@@ -267,6 +275,10 @@ class Phone(Model):
     area_code = textattribute("areaCode")
     subscriber_number = textattribute("subscriberNumber")
 
+    def __eq__(self, other):
+        attributes = ['country_code', 'area_code', 'subscriber_number']
+        return all(getattr(self, attr, None) == getattr(other, attr, None) for attr in attributes)
+
     def __str__(self):
         """Return the string representation of phone number."""
         return "%s %s %s" % (self.country_code, self.area_code, self.subscriber_number)
@@ -310,6 +322,8 @@ class Customer(Model):
     address = submodel(Address, "address")
     phone = submodel(Phone, "phone")
     fax = submodel(Phone, "fax")
+    additional_data = submodel(Model, "additionalData")
+    extension_additional_data = submodel(Model, "additionalData")
 
     def __str__(self):
         return str(self.handle)
@@ -365,7 +379,29 @@ class SSLOrder(Model):
     certificate
     rootCertificate
     """
-    pass
+
+    @property
+    def validation_details(self):
+        details = []
+
+        try:
+            for item in self.additionalData.array:
+                if hasattr(item.item, 'dnsRecord'):
+                    details.append(SSLOrderDnsValidationInfo(item.item))
+        except AttributeError:
+            pass
+
+        return details
+
+
+class SSLOrderDnsValidationInfo(Model):
+    """
+    Information about DV through DNS.
+
+    domain
+    dns_record
+    dns_value
+    """
 
 
 class Extension(Model):
